<?php
/**
 * @file
 * Administration form for Social Counters.
 */

/**
 * Builds form for drupal_get_form() call in social_counters_admin_menu().
 */
function social_counters_admin_form($form, $form_state) {

  $form['social_counters'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Social Counters'),
    '#collapsible' => FALSE,
  );

  $form['social_counters']['facebook'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Facebook'),
    '#collapsible' => TRUE,
  );
  $form['social_counters']['facebook']['social_counters_facebook_uid'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Facebook Page Name (or User ID)'),
    '#description'   => t("Either the page name or ID. Examples: 'coca-cola' or '40796308305'."),
    '#default_value' => variable_get('social_counters_facebook_uid', ''),
    '#required'      => FALSE,
  );

  $form['social_counters']['twitter'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Twitter'),
    '#collapsible' => TRUE,
  );
  if (module_exists('oauth_common')) {
    $form['social_counters']['twitter']['social_counters_twitter_account'] = array(
      '#type'          => 'textfield',
      '#title'         => t('Twitter account'),
      '#description'   => t('The Twitter account to pull the number of followers.'),
      '#default_value' => variable_get('social_counters_twitter_account', ''),
      '#required'      => FALSE,
    );

    $form['social_counters']['twitter']['social_counters_twitter_oauth_consumer_key'] = array(
      '#type'          => 'textfield',
      '#title'         => t('OAuth Consumer Key'),
      '#default_value' => variable_get('social_counters_twitter_oauth_consumer_key', ''),
    );
    $form['social_counters']['twitter']['social_counters_twitter_oauth_consumer_secret'] = array(
      '#type'          => 'textfield',
      '#title'         => t('OAuth Consumer Secret'),
      '#default_value' => variable_get('social_counters_twitter_oauth_consumer_secret', ''),
    );
    $form['social_counters']['twitter']['social_counters_twitter_oauth_token'] = array(
      '#type'          => 'textfield',
      '#title'         => t('OAuth Token'),
      '#default_value' => variable_get('social_counters_twitter_oauth_token', ''),
    );
    $form['social_counters']['twitter']['social_counters_twitter_oauth_secret'] = array(
      '#type'          => 'textfield',
      '#title'         => t('OAuth Secret'),
      '#default_value' => variable_get('social_counters_twitter_oauth_secret', ''),
    );
  }
  else {
    $form['social_counters']['twitter']['oauth_missing'] = array(
      '#type'   => 'item',
      '#title'  => t('OAuth module is missing'),
      '#markup' => t("Twitter functionality deppends on the <a href='https://drupal.org/project/oauth'>OAuth module</a>."),
    );
  }

  $form['social_counters']['vk'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('VK'),
    '#collapsible' => TRUE,
  );
  $form['social_counters']['vk']['social_counters_vk_group_id'] = array(
    '#type'          => 'textfield',
    '#title'         => t('VK Group ID'),
    '#description'   => t("The group ID of a VK Group."),
    '#default_value' => variable_get('social_counters_vk_group_id', ''),
    '#required'      => FALSE,
  );
  $form['social_counters']['vk']['social_counters_vk_group_url'] = array(
    '#type'          => 'textfield',
    '#title'         => t('VK Group url'),
    '#description'   => t("The URL of the group."),
    '#default_value' => variable_get('social_counters_vk_group_url', ''),
    '#required'      => FALSE,
  );

  $form['social_counters']['google_plus'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Google Plus'),
    '#collapsible' => TRUE,
  );

  $form['social_counters']['google_plus']['social_counters_google_plus_uid'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Google Plus Name (or User ID)'),
    '#description'   => t("Either the page name or ID. Examples: 'coca-cola' or '40796308305'."),
    '#default_value' => variable_get('social_counters_google_plus_uid', ''),
    '#required'      => FALSE,
  );

  $form['social_counters']['google_plus']['social_counters_google_plus_key'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Google Plus API Key'),
    '#description'   => t('You can generate Google Plus API Key here !link.', array(
        '!link' => l('https://developers.google.com/api-client-library/python/guide/aaa_apikeys',
      'https://developers.google.com/api-client-library/python/guide/aaa_apikeys'))
    ),
    '#default_value' => variable_get('social_counters_google_plus_key', ''),
    '#required'      => FALSE,
  );

  $form['social_counters']['override'] = array(
    '#type'        => 'fieldset',
    '#title'       => t('Override counters'),
    '#description' => t('You should leave the fields below as they are. The values will be populated on cron.'),
    '#collapsible' => TRUE,
  );
  $form['social_counters']['override']['social_counters_facebook_likes'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Facebook likes'),
    '#description'   => t('The number of likes.'),
    '#default_value' => variable_get('social_counters_facebook_likes', ''),
    '#required'      => FALSE,
  );
  $form['social_counters']['override']['social_counters_twitter_followers'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Twitter followers'),
    '#description'   => t('The number of followers.'),
    '#default_value' => variable_get('social_counters_twitter_followers', ''),
    '#required'      => FALSE,
  );
  $form['social_counters']['override']['social_counters_vk_members_count'] = array(
    '#type'          => 'textfield',
    '#title'         => t('VK members count'),
    '#description'   => t('The number members in the vk group'),
    '#default_value' => variable_get('social_counters_vk_members_count', 0),
    '#required'      => FALSE,
  );
   $form['social_counters']['override']['social_counters_google_plus_followers'] = array(
    '#type'          => 'textfield',
    '#title'         => t('Google Plus followers'),
    '#description'   => t('The number of followers.'),
    '#default_value' => variable_get('social_counters_google_plus_followers', 0),
    '#required'      => FALSE,
  );

  return system_settings_form($form);
}
